package org.apache.bcel.verifier.structurals;

import java.util.HashMap;
import java.util.HashSet;
import java.util.Map;
import java.util.Set;
import org.apache.bcel.generic.CodeExceptionGen;
import org.apache.bcel.generic.InstructionHandle;
import org.apache.bcel.generic.MethodGen;

/* loaded from: org_apache_bcel_verifier_structurals.jar:org/apache/bcel/verifier/structurals/ExceptionHandlers.class */
public class ExceptionHandlers {
    private static final ExceptionHandler[] EMPTY_ARRAY = new ExceptionHandler[0];
    private final Map<InstructionHandle, Set<ExceptionHandler>> exceptionHandlers = new HashMap();

    public ExceptionHandlers(MethodGen mg) {
        CodeExceptionGen[] cegs = mg.getExceptionHandlers();
        for (CodeExceptionGen ceg : cegs) {
            ExceptionHandler eh = new ExceptionHandler(ceg.getCatchType(), ceg.getHandlerPC());
            InstructionHandle startPC = ceg.getStartPC();
            while (true) {
                InstructionHandle ih = startPC;
                if (ih != ceg.getEndPC().getNext()) {
                    this.exceptionHandlers.computeIfAbsent(ih, k -> {
                        return new HashSet();
                    }).add(eh);
                    this.exceptionHandlers.computeIfAbsent(ih, k2 -> {
                        return new HashSet();
                    }).add(eh);
                    startPC = ih.getNext();
                }
            }
        }
    }

    public ExceptionHandler[] getExceptionHandlers(InstructionHandle ih) {
        Set<ExceptionHandler> hsSet = this.exceptionHandlers.get(ih);
        if (hsSet == null) {
            return EMPTY_ARRAY;
        }
        return (ExceptionHandler[]) hsSet.toArray(ExceptionHandler.EMPTY_ARRAY);
    }
}
